#
# spec file for package codelite
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012-2014 Mariusz Fik <fisiu@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           codelite
Version:        5.4
Release:        6.24
Summary:        Powerful open-source, cross platform code editor for the C/C++
License:        GPL-3.0+
Group:          Development/Tools/IDE
Url:            http://codelite.org/
Source0:        https://downloads.sourceforge.net/project/codelite/Mirrors/%{name}-%{version}-gtk.src.tar.gz
Source1:        %{name}.desktop
Source2:        %name-rpmlintrc
# PATCH-FIX-OPENSUSE codelite-date-time-usage-fix.patch fisiu@opensuse.org -- It removes usage of __DATE__ and __TIME__
Patch0:         %{name}-date-time-usage-fix.patch
# PATCH-FEATURE-OPENSUSE codelite-disable-new-version-check.patch fisiu@opensuse.org -- Disable 'new version' check on startup
Patch1:         %{name}-disable-new-version-check.patch
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
BuildRequires:  libmysqlclient-devel
BuildRequires:  llvm-clang-devel
BuildRequires:  wxWidgets-devel >= 3.0.0
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libssh)
%define _use_internal_dependency_generator 0
%if 0%{?suse_version} > 1320
Requires:       xterm-bin
%else
Requires:       xterm
%endif
Recommends:     gcc
Recommends:     wxWidgets-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CodeLite is a powerful open-source, cross platform code editor for the C/C++
programming language. It uses a sophisticated, yet intuitive interface which
allows user easily to create, build and debug complex projects.

%prep
%setup -q
%patch0 -p0
%patch1 -p0
### FIXME: Bug reported, remove line belowe with next codelite version update.
mv -v translations/cz translations/zh_CN

%build
mkdir build && cd build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

cmake .. \
    -DCMAKE_BUILD_TYPE=Debug \
    -DCMAKE_SKIP_RPATH=ON \
    -DENABLE_CLANG=1 \
    -DWITH_MYSQL=1 \
    -DWITH_WXC=0 \
    -DCOPY_WX_LIBS=0

make %{?_smp_mflags}

%install
pushd build
%makeinstall
popd

### Install desktop menu entry
install -D -m 644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
### Fix desktop menu icon
install -D Runtime/images/cubes.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

### Add mime types
mkdir -p %{buildroot}%{_datadir}/mime/packages/
cp -p %{name}.xml %{buildroot}%{_datadir}/mime/packages/
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/32x32/mimetypes/
cp -p %{buildroot}%{_datadir}/%{name}/images/cubes.png %{buildroot}%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-workspace.png
cp -p %{buildroot}%{_datadir}/%{name}/images/cubes.png %{buildroot}%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-project.png

%if 0%{?suse_version}
### Search for duplicates
%fdupes %{buildroot}%{_prefix}
### Update translation in desktop menu entry
%suse_update_desktop_file %{name}
%endif

### Fix for wrong-script-end-of-line-encoding
dos2unix %{buildroot}%{_bindir}/%{name}_kill_children

### Fix unstripped-binary-or-object warning for SLE and openSUSE
%if 0%{?sles_version} == 11
strip -s -v %{buildroot}%{_bindir}/%{name}{,_indexer,_cppcheck,gcc,-clang}
strip -s -v %{buildroot}%{_libdir}/%{name}/*.so
strip -s -v %{buildroot}%{_libdir}/%{name}/debuggers/*.so
%else
strip -s -v %{buildroot}%{_libdir}/%{name}/libclang.so
%endif

%clean
%{?buildroot:rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc about.html AUTHORS 
%{_bindir}/%{name}*
%{_bindir}/clg++
%{_bindir}/clgcc
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-workspace.png
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-%{name}-project.png
### TODO Shoould we put it in separate -lang package?
%{_datadir}/locale/cs/LC_MESSAGES/codelite.mo
%{_datadir}/locale/zh_CN/LC_MESSAGES/codelite.mo

%post
update-mime-database %{_datadir}/mime >/dev/null 2>&1 || :
update-desktop-database >/dev/null 2>&1 || :
touch --no-create %{_datadir}/icons/hicolor >/dev/null 2>&1 || :

%postun
update-mime-database %{_datadir}/mime >/dev/null 2>&1 || :
update-desktop-database >/dev/null 2>&1 || :
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor >/dev/null 2>&1
    gtk-update-icon-cache %{_datadir}/icons/hicolor >/dev/null 2>&1 || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor >/dev/null 2>&1 || :

%changelog
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in postun scripts
* Tue Sep 23 2014 sfalken@opensuse.org
- Removed %%wx_requires as it is no longer a valid macro
* Tue Mar 18 2014 fisiu@opensuse.org
- Fix source tarball url.
* Fri Jan 24 2014 fisiu@opensuse.org
- Update to 5.4:
  + New cmake plugin.
  + New tweak plugin.
  + Improved git plugin.
  + codelite-terminal: new terminal emulator.
  + Many enhancements and bug fixes.
* Fri Jan 24 2014 fisiu@opensuse.org
- Update to 5.3:
  + Brand new SFTP plugin.
  + codelite-make: a command-line tool to generate Makefiles from codelite's
    project.
  + Improved git, database explorer, cscope and Wizard plugins.
  + Bug fixes.
* Fri Nov  8 2013 fisiu@opensuse.org
- Change previous cmake parameter to -DCMAKE_SKIP_RPATH=ON. Fix bnc#848791.
* Thu Sep 12 2013 toganm@opensuse.org
- add -DCMAKE_SKIP_INSTALL_RPATH=ON to cmake options
* Tue Jul 16 2013 fisiu@opensuse.org
- Update to 5.2:
  + Added disassemble window to the debugger
  + Better dark theme visualization
  + Improved tab appearance
  + Debugger pretty printing improvements
  + Various dialogs were re-designed (setters/getters)
  + Improved code completion
  + and much more
- Enable db explorer plugin with mariadb/mysql support.
* Wed Jun 12 2013 dvaleev@suse.com
- Add llvm-clang-devel to buildrequires, so the archs other than
  x86 would find -lclang
* Mon May 27 2013 fisiu@opensuse.org
- Change license to GPL-3.0+, fix bnc#821637.
* Thu May 16 2013 fisiu@opensuse.org
- Enable manual stripping for SLE.
* Wed May 15 2013 fisiu@opensuse.org
- Fix missing license's text in About dialog.
* Wed Apr 10 2013 fisiu@opensuse.org
- Update to 5.1:
  + Build with CMake
  + Czech translation
  + New highlight theme "Zmrok-like"
  + Improved git support
  + Code completion enhancements
  + Many bug fixes
- Patch codelite-4.1.5770-disable-autoupdate-by-default.patch was
  updated and renamed to codelite-disable-new-version-check.patch
* Fri Feb  1 2013 fisiu@opensuse.org
- Update to 5.0.6213:
  + Support for GUI RAD wxCrafter: http://wxcrafter.codelite.org
  + New plugin Zoom Navigato
  + New "New Project" dialog
  + Quick code navigation with Shift-Click (configurable)
  + Various updates to code completion
  + More bugs fixed
- Drop codelite-no-return-fix.patch: fixed upstream
- Codelite needs wxWidgets >= 2.9.4
* Tue Sep 25 2012 svalx@svalx.net
- Update to 4.1.5770:
  + "Symbol View" is now deprecated infavor of the "Outline" plugin
  + Clang code completion improvements:
  + Codelite's Makefiles are more standard (they are now using the
    standard CXX, CC, AR, CFLAGS and CXXFLAGS variables).
- Add codelite-no-return-fix.patch for fix
  no-return-in-nonvoid-function error
- Build on SLE11-SP2 whith wxGTK 2.8.8
- Add codelite-4.1.5770-disable-autoupdate-by-default.patch.
- Add some fields to desktop file.
- Changes in spec file:
  + Add MIME types for workspace and project;
  + Remove URL path from source0;
  + Use %%{__make} macros;
  + Remove duplicate GPL file from %%{_datadir};
  + Add some configure options;
  + Add %%clean section.
  + Manual strip binaries for SLE11-SP2
* Tue Jun 19 2012 fisiu@opensuse.org
- Update to 4.0.5589:
  + Enhanced support for svn, works with svn 1.7.
  + Items in debugger tooltip are editable.
  + Support for clang up to 3.2.
  + C++11 completion can be turned ON/OFF.
  + New icon set added.
  + Added CallGraph plugin.
* Sat Apr  7 2012 fisiu@opensuse.org
- Update to 3.5.5375:
  + Code completion speed improvements.
  + An improved clang code completion (with libclang).
  + New perspective management.
  + Many bug fixes.
  + Infrastructure improvements.
- Add codelite-date-time-usage-fix.patch.
* Mon Jan 24 2011 fisiu@opensuse.org
- build against wxWidgets-wxcontainer-devel instead wxGTK-devel for
  openSUSE > 11.3
* Mon Jan  3 2011 fisiu@opensuse.org
- upstream update to 2.9.0.4684:
  + Many bug fixes
  + Subversion plugin enhancements
  + Improved debugging
* Mon Nov  1 2010 fisiu@opensuse.org
- upstream update to 2.8.0.4537:
  + Many bug fixes
  + Debugger interface revamp
  + Find In Files improvements:
  - New options: ignore matches founds in comments or string
  - Color matches in comments using the editor's comment color
  + New: 'Find References'
* Wed Oct 13 2010 fisiu@opensuse.org
- upstream update to 2.7.0.4375:
  + Many bug fixes
  + New look
  + Code completion enhancements ( Macros improvement, More complex templates handling and much more )
  + New refactoring: Rename Local Variable
* Wed Jun  9 2010 fisiu@opensuse.org
- upstream update to 2.5.3.4075
  + code completion enhancements
  + many bugs were fixed
* Mon Apr 12 2010 fisiu@opensuse.org                              
- upstream update to 2.5.2.4031
  + Introducing wxAUI docking system + notebooks
  + Improvements to the debugger
  + code completion enhancements
  + Many UI changes
  + Many bugs were fixed
* Wed Mar  3 2010 fisiu@opensuse.org                              
- upstream update to 2.3.0.3833
  + Major improvements in the Code Completion
  + SymbolView plugin
  + Simplified search methods
  + Many bugs were fixed
* Tue Feb  2 2010 fisiu@opensuse.org
- upstream update to 2.2.0.3681
  + Introducing the environment variables set - define environment variable set per workspace
  + Subversion plugin - many bug fixes + improvements
  + Incremental search: Now with Replace options!
  + Improved function calltip
* Tue Jan 19 2010 fisiu@opensuse.org
- BuildRequires moved from wxWidgets to wxGTK
* Wed Dec 30 2009 fisiu@opensuse.org
- upstream update to 2.1.0.3584
* Wed Nov 18 2009 fisiu82@gmail.com
- new upstream release 2.0.3365
* Tue Oct 27 2009 fisiu82@gmail.com
- upstream update to 1.0.3035:
  + Compiler annotations and edit margin
  + New Debugger ASCII viewer
  + Better breakpoint handling
  + Get more from gdb!
  + C/C++ static code analysis by CppCheck!
  + Improved Setters / Getters dialog!
* Wed May 27 2009 fisiu82@gmail.com
- upstream update, 1.0.2841
* Mon Apr 20 2009 fisiu82@gmail.com
- upstream update, 1.0.2819
* Fri Mar  6 2009 fisiu82@gmail.com
- initial package, 1.0.2785
